package com.css.simulation.resource.scheduler.consumer;


import api.common.pojo.dto.ProjectMessageDTO;
import api.common.util.JsonUtil;
import com.css.simulation.resource.scheduler.service.ProjectService;
import com.css.simulation.resource.scheduler.util.ProjectUtil;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

@Component
@Slf4j
public class ProjectConsumer {
    @Resource
    private ProjectService projectService;
    @Resource
    private ProjectUtil projectUtil;


    /**
     * @param projectRecord 项目启动消息
     */
    @KafkaListener(groupId = "simulation-resource-scheduler", topics = "${custom.mq-start-project-topic}")
    @SneakyThrows
    public void acceptMessage(ConsumerRecord<String, String> projectRecord) {
        final ProjectMessageDTO projectMessageDTO = JsonUtil.jsonToBean(projectRecord.value(), ProjectMessageDTO.class);
        log.info("接收到项目开始消息为：" + projectMessageDTO);
        new Thread(() -> projectService.createTaskAndFixData(projectMessageDTO), "fix-" + projectMessageDTO.getProjectId()).start();
    }

    //* -------------------------------- 结束 --------------------------------

    @KafkaListener(groupId = "simulation-resource-scheduler", topics = "${custom.mq-stop-project-topic}")
    @SneakyThrows
    public void stopProject(ConsumerRecord<String, String> stopRecord) {
        log.info("接收到的项目终止消息为：" + stopRecord);
        JsonNode jsonNode = new ObjectMapper().readTree(stopRecord.value());
        String projectId = jsonNode.path("projectId").asText();
        String projectType = jsonNode.path("type").asText();
        String isChoiceGpu = projectUtil.getIsChoiceGpuByProjectId(projectId);
        projectService.stopProject(isChoiceGpu, projectType, projectId);
    }


}
