package com.css.simulation.resource.scheduler.scheduler;

import api.common.pojo.dto.ProjectMessageDTO;
import api.common.util.CollectionUtil;
import api.common.util.JsonUtil;
import com.css.simulation.resource.scheduler.consumer.ProjectConsumer;
import com.css.simulation.resource.scheduler.util.ProjectUtil;
import com.css.simulation.resource.scheduler.util.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;

@Component
@Slf4j
public class ProjectScheduler {
    @Resource
    private StringRedisTemplate stringRedisTemplate;
    @Resource
    private ProjectConsumer projectConsumer;
    @Resource
    private ProjectUtil projectUtil;

    /**
     * 调度项目启动
     */
    @Scheduled(fixedDelay = 5000)
    public void dispatchProject() {
        List<String> projectMessageKeys = projectUtil.getWaitingProjectMessageKeys();
        if (!CollectionUtil.isEmpty(projectMessageKeys)) {
            log.info("尝试启动等待中的项目：" + projectMessageKeys);
            for (String projectMessageKey : projectMessageKeys) {
                final String projectMessage = RedisUtil.getStringByKey(stringRedisTemplate, projectMessageKey);
                projectConsumer.cacheProject(JsonUtil.jsonToBean(projectMessage, ProjectMessageDTO.class));
            }
        }
    }

}
